@@ -28,18 +28,6 @@ def markdown_filter(value):
     out = marked.convert(output)
     return out
 
-def filter_hidden_files(filename):
-    _name = os.path.basename(filename)
-    _path = os.path.dirname(filename)
-
-    for _segment in _path.split(os.sep):
-        if _segment.startswith("."):
-            return False
-    if _name.startswith("."):
-        return False;
-    print _name
-
-    return True;
 
 
 class JinjaStaticRenderer(Core.Renderer):
@@ -71,10 +59,24 @@ class JinjaStaticRenderer(Core.Renderer):
         self.env.compile_templates(
             self.config['compiled_templates_file'],
             ignore_errors=False,
-            filter_func=filter_hidden_files 
+            filter_func=self.filter_hidden_files 
             )
 
         self.reporter.verbose("Compile templates to .zip: \033[32m%s\033[0m" % (self.config['compiled_templates_file']))
+    
+    def filter_hidden_files(self, filename):
+        _name = os.path.basename(filename)
+        _path = os.path.dirname(filename)
+
+        for _segment in _path.split(os.sep):
+            if _segment.startswith("."):
+                return False
+        if _name.startswith("."):
+            return False;
+        
+        self.reporter.verbose("Loading template: %s" % (_name))
+
+        return True;
 
 
     def get_template_mtime(self, template):
